NAME
Quizzer::Element::Text::String - password input field
DESCRIPTION
This is a string input field, presented to the user using a plain text interface.
Quizzer::Element::Text::String - password input field
This is a string input field, presented to the user using a plain text interface.